==> xshisen-1.35.tar.gz: xshisen-1.35/fallback.h <==
static char *fallback_resources[] = {
    "*connectLineColor: blue",
    "*connectLineTime: 1200",
    "*aboutString: Shisen-sho for X11 ver " XSHISEN_VERSION " \\n\\n"
    " Shisen-sho for X11    by Masaoki Kobayashi (masaoki@tky.hp.com)\\n"
    "   Shisen-sho for Win  by Shinji Ono (HFC02755@niftyserve.or.jp)\\n"
    "   Picture             by Takayuki Akiyama",
    "*tedumari: No pieces available to get",
    "*timeFormat: Your time is %2.2d:%2.2d.",
    "*displayFormat1: Pieces left: ",
    "*displayFormat2: Time: ",
    "*score*scoreTitle: Shisen-sho best scores\\n\\n",
    "*score*strPeriod: Last %d days",
    "*score*strPlayed: Played",
    "*score*strCompleted: Completed",
    "*score*strTedumari: Deadlocked",
    "*score*strSearched: Search used",
    "*score*strGames: games",
    "*score*strAverage: Average",
    "*score*strTotal: Total",
    "*score*strGiveUp: Given up",
    "*score*personalTitle: Personal Statistics (%s)\\n\\n",
    "*score*averagePeriod: 14",
#if USE_MOTIF
    "*form.label0.foreground: #f0f0f0",
    "*form.label1.foreground: #f0f0f0",
    "*form.label2.foreground: #f0f0f0",
    "*form.label3.foreground: #f0f0f0",
    "*form.label0.background: #004000",
    "*form.label1.background: #004000",
    "*form.label2.background: #004000",
    "*form.label3.background: #004000",
    "*fontList: -*-fixed-medium-r-normal--16-*-iso8859-1",
    "*drawing.foreground: #f0f0f0",
    "*drawing.background: #004000",
    "*score.dialogTitle: XShisen Score",
    "*message.dialogTitle: XShisen",
    "*mdialog.dialogTitle: Warning",
    "*mdialog.messageString: Cannot write to high-score file.",
    "*mdialog.okLabelString: Retry",
    "*mdialog.cancelLabelString: Abandon",
    "*mb.button_0.labelString: Game",
    "*mb.button_0.mnemonic: G",
    "*mb.button_1.labelString: Operation",
    "*mb.button_1.mnemonic: O",
    "*mb.button_2.labelString: Configuration",
    "*mb.button_2.mnemonic: C",
    "*pd0.button_0.labelString: Start",
    "*pd0.button_0.mnemonic: D",
    "*pd0.button_0.accelerator: Ctrl<Key>D",
    "*pd0.button_0.acceleratorText: Ctrl-D",
    "*pd0.button_1.labelString: Restart",
    "*pd0.button_1.mnemonic: R",
    "*pd0.button_1.accelerator: Ctrl<Key>R",
    "*pd0.button_1.acceleratorText: Ctrl-R",
    "*pd0.button_2.labelString: Pause",
    "*pd0.button_2.mnemonic: P",
    "*pd0.button_2.accelerator: <Key>Escape",
    "*pd0.button_2.acceleratorText: ESC",
    "*pd0.button_3.labelString: Score",
    "*pd0.button_3.mnemonic: S",
    "*pd0.button_3.accelerator: Ctrl<Key>S",
    "*pd0.button_3.acceleratorText: Ctrl-S",
    "*pd0.button_4.labelString: Personal Score",
    "*pd0.button_4.mnemonic: T",
    "*pd0.button_4.accelerator: Ctrl<Key>T",
    "*pd0.button_4.acceleratorText: Ctrl-T",
    "*pd0.button_5.labelString: About",
    "*pd0.button_5.mnemonic: A",
    "*pd0.button_5.accelerator: Ctrl<Key>A",
    "*pd0.button_5.acceleratorText: Ctrl-A",
    "*pd0.button_6.labelString: Exit",
    "*pd0.button_6.mnemonic: x",
    "*pd1.button_0.labelString: Search",
    "*pd1.button_0.mnemonic: S",
    "*pd1.button_0.accelerator: <Key>F1",
    "*pd1.button_0.acceleratorText: F1",
    "*pd1.button_1.labelString: Back",
    "*pd1.button_1.mnemonic: B",
    "*pd1.button_1.accelerator: <Key>F5",
    "*pd1.button_1.acceleratorText: F5",
    "*pd2.button_0.labelString: Regular (18x 8)",
    "*pd2.button_1.labelString: Large   (24x12)",
    "*pd2.button_2.labelString: Huge    (36x16)",
    "*pd2.button_3.labelString: Click Trial",
    "*pd2.button_4.labelString: Gravity",
    "*drawing.translations: #replace <Btn1Down>: PickupPiece()\\n"
    "  <Btn2Down>(2): menu(0,0)\\n",
    "  <Btn3Down>: CancelPiece()",
#else /* USE_MOTIF */
    "*form.sform.label0.foreground: #f0f0f0",
    "*form.sform.label1.foreground: #f0f0f0",
    "*form.sform.label2.foreground: #f0f0f0",
    "*form.sform.label3.foreground: #f0f0f0",
    "*form.sform.label0.background: #004000",
    "*form.sform.label1.background: #004000",
    "*form.sform.label2.background: #004000",
    "*form.sform.label3.background: #004000",
    "*font: -*-fixed-medium-r-normal--16-*-iso8859-1",
    "*simple.foreground: #f0f0f0",
    "*sform*background: #004000",
    "*score.title: XShisen Score",
    "*message.title: XShisen",
    "*mdialog.title: Warning",
    "*mdialog.label.label: Cannot write to high-score file.",
    "*mdialog.ok_button.label: Retry",
    "*mdialog.cancel_button.label: Abandon",
    "*mb.pd0.label: Game",
    "*mb.pd1.label: Operation",
    "*mb.pd2.label: Configuration",
    "*pd0*button_0.label: Start          Ctrl-D",
    "*pd0*button_1.label: Restart        Ctrl-R",
    "*pd0*button_2.label: Pause          ESC",
    "*pd0*button_3.label: Score          Ctrl-S",
    "*pd0*button_4.label: Personal Score Ctrl-T",
    "*pd0*button_5.label: About          Ctrl-A",
    "*pd0*button_6.label: Exit",
    "*pd1*button_0.label: Search  F1",
    "*pd1*button_1.label: Back    F5",
    "*pd2*button_0.label: Regular (18x 8)",
    "*pd2*button_1.label: Large   (24x12)",
    "*pd2*button_2.label: Huge    (36x16)",
    "*pd2*button_3.label: Click Trial",
    "*pd2*button_4.label: Gravity",
    "*sform*translations: #replace <Btn1Down>: PickupPiece()\\n"
    "  <Btn2Down>(2): menu(0,0)\\n",
    "  <Btn3Down>: CancelPiece()\\n"
    "  Ctrl<Key>D: menu(0,0)\\n"
    "  Ctrl<Key>R: menu(0,1)\\n"
    "  <Key>Escape: menu(0,2)\\n"
    "  Ctrl<Key>S: menu(0,3)\\n"
    "  Ctrl<Key>T: menu(0,4)\\n"
    "  Ctrl<Key>A: menu(0,5)\\n"
    "  <Key>F1: menu(1,0)\\n"
    "  <Key>F5: menu(1,1)",
#endif /* USE_MOTIF */
    NULL
};

==> xshisen-1.36.tar.gz: xshisen-1.36/fallback.h <==
static char *fallback_resources[] = {
    "*connectLineColor: blue",
    "*connectLineTime: 1200",
    "*aboutString: Shisen-sho for X11 ver " XSHISEN_VERSION " \\n\\n"
    " Shisen-sho for X11    by Masaoki Kobayashi (masaoki@techfirm.co.jp)\\n"
    "   Shisen-sho for Win  by Shinji Ono (HFC02755@nifty.ne.jp)\\n"
    "   Picture             by Takayuki Akiyama",
    "*tedumari: No pieces available to get",
    "*timeFormat: Your time is %2.2d:%2.2d.",
    "*displayFormat1: Pieces left: ",
    "*displayFormat2: Time: ",
    "*score*scoreTitle: Shisen-sho best scores\\n\\n",
    "*score*strPeriod: Last %d days",
    "*score*strPlayed: Played",
    "*score*strCompleted: Completed",
    "*score*strTedumari: Deadlocked",
    "*score*strSearched: Search used",
    "*score*strGames: games",
    "*score*strAverage: Average",
    "*score*strTotal: Total",
    "*score*strGiveUp: Given up",
    "*score*personalTitle: Personal Statistics (%s)\\n\\n",
    "*score*averagePeriod: 14",
#if USE_MOTIF
    "*form.label0.foreground: #f0f0f0",
    "*form.label1.foreground: #f0f0f0",
    "*form.label2.foreground: #f0f0f0",
    "*form.label3.foreground: #f0f0f0",
    "*form.label0.background: #004000",
    "*form.label1.background: #004000",
    "*form.label2.background: #004000",
    "*form.label3.background: #004000",
    "*fontList: -*-fixed-medium-r-normal--16-*-iso8859-1",
    "*drawing.foreground: #f0f0f0",
    "*drawing.background: #004000",
    "*score.dialogTitle: XShisen Score",
    "*message.dialogTitle: XShisen",
    "*mdialog.dialogTitle: Warning",
    "*mdialog.messageString: Cannot write to high-score file.",
    "*mdialog.okLabelString: Retry",
    "*mdialog.cancelLabelString: Abandon",
    "*mb.button_0.labelString: Game",
    "*mb.button_0.mnemonic: G",
    "*mb.button_1.labelString: Operation",
    "*mb.button_1.mnemonic: O",
    "*mb.button_2.labelString: Configuration",
    "*mb.button_2.mnemonic: C",
    "*pd0.button_0.labelString: Start",
    "*pd0.button_0.mnemonic: D",
    "*pd0.button_0.accelerator: Ctrl<Key>D",
    "*pd0.button_0.acceleratorText: Ctrl-D",
    "*pd0.button_1.labelString: Restart",
    "*pd0.button_1.mnemonic: R",
    "*pd0.button_1.accelerator: Ctrl<Key>R",
    "*pd0.button_1.acceleratorText: Ctrl-R",
    "*pd0.button_2.labelString: Pause",
    "*pd0.button_2.mnemonic: P",
    "*pd0.button_2.accelerator: <Key>Escape",
    "*pd0.button_2.acceleratorText: ESC",
    "*pd0.button_3.labelString: Score",
    "*pd0.button_3.mnemonic: S",
    "*pd0.button_3.accelerator: Ctrl<Key>S",
    "*pd0.button_3.acceleratorText: Ctrl-S",
    "*pd0.button_4.labelString: Personal Score",
    "*pd0.button_4.mnemonic: T",
    "*pd0.button_4.accelerator: Ctrl<Key>T",
    "*pd0.button_4.acceleratorText: Ctrl-T",
    "*pd0.button_5.labelString: About",
    "*pd0.button_5.mnemonic: A",
    "*pd0.button_5.accelerator: Ctrl<Key>A",
    "*pd0.button_5.acceleratorText: Ctrl-A",
    "*pd0.button_6.labelString: Exit",
    "*pd0.button_6.mnemonic: x",
    "*pd1.button_0.labelString: Search",
    "*pd1.button_0.mnemonic: S",
    "*pd1.button_0.accelerator: <Key>F1",
    "*pd1.button_0.acceleratorText: F1",
    "*pd1.button_1.labelString: Back",
    "*pd1.button_1.mnemonic: B",
    "*pd1.button_1.accelerator: <Key>F5",
    "*pd1.button_1.acceleratorText: F5",
    "*pd2.button_0.labelString: Regular (18x 8)",
    "*pd2.button_1.labelString: Large   (24x12)",
    "*pd2.button_2.labelString: Huge    (36x16)",
    "*pd2.button_3.labelString: Click Trial",
    "*pd2.button_4.labelString: Gravity",
    "*drawing.translations: #replace <Btn1Down>: PickupPiece()\\n"
    "  <Btn2Down>(2): menu(0,0)\\n",
    "  <Btn3Down>: CancelPiece()",
#else /* USE_MOTIF */
    "*form.sform.label0.foreground: #f0f0f0",
    "*form.sform.label1.foreground: #f0f0f0",
    "*form.sform.label2.foreground: #f0f0f0",
    "*form.sform.label3.foreground: #f0f0f0",
    "*form.sform.label0.background: #004000",
    "*form.sform.label1.background: #004000",
    "*form.sform.label2.background: #004000",
    "*form.sform.label3.background: #004000",
    "*font: -*-fixed-medium-r-normal--16-*-iso8859-1",
    "*simple.foreground: #f0f0f0",
    "*sform*background: #004000",
    "*score.title: XShisen Score",
    "*message.title: XShisen",
    "*mdialog.title: Warning",
    "*mdialog.label.label: Cannot write to high-score file.",
    "*mdialog.ok_button.label: Retry",
    "*mdialog.cancel_button.label: Abandon",
    "*mb.pd0.label: Game",
    "*mb.pd1.label: Operation",
    "*mb.pd2.label: Configuration",
    "*pd0*button_0.label: Start          Ctrl-D",
    "*pd0*button_1.label: Restart        Ctrl-R",
    "*pd0*button_2.label: Pause          ESC",
    "*pd0*button_3.label: Score          Ctrl-S",
    "*pd0*button_4.label: Personal Score Ctrl-T",
    "*pd0*button_5.label: About          Ctrl-A",
    "*pd0*button_6.label: Exit",
    "*pd1*button_0.label: Search  F1",
    "*pd1*button_1.label: Back    F5",
    "*pd2*button_0.label: Regular (18x 8)",
    "*pd2*button_1.label: Large   (24x12)",
    "*pd2*button_2.label: Huge    (36x16)",
    "*pd2*button_3.label: Click Trial",
    "*pd2*button_4.label: Gravity",
    "*sform*translations: #replace <Btn1Down>: PickupPiece()\\n"
    "  <Btn2Down>(2): menu(0,0)\\n",
    "  <Btn3Down>: CancelPiece()\\n"
    "  Ctrl<Key>D: menu(0,0)\\n"
    "  Ctrl<Key>R: menu(0,1)\\n"
    "  <Key>Escape: menu(0,2)\\n"
    "  Ctrl<Key>S: menu(0,3)\\n"
    "  Ctrl<Key>T: menu(0,4)\\n"
    "  Ctrl<Key>A: menu(0,5)\\n"
    "  <Key>F1: menu(1,0)\\n"
    "  <Key>F5: menu(1,1)",
#endif /* USE_MOTIF */
    NULL
};
